==> Convert-YText-v0.1.1_1.tar.gz: Convert-YText-v0.1.1_1/t/corpus.pl <==
# Data from t/tests.t in Email::Address 1.892. 
# License is the same as this module.
sub corpus {
return (
q{"Edwards, Darryl" <Darryl.Edwards@adc.com>},
q{"Chris Devers" <cdevers@boston.com>},
q{"Greg Norris" <nextrightmove@bang.example.net> (humble visionary genius)},
q{"Frank Schmuck, CFO" <fschmuck@l.example.org>},
q{regn@ExamPle.com},
q{"'abigail@foad.example.biz'" <abigail@foad.example.biz>},
q{"'advocacy@p.example.org'" <advocacy@p.example.org>},
q{"Horsley Tom" <Tom.Horsley@ccur.com>},
q{"'Tom Christiansen'" <tchrist@chthon.perl.com>},
q{"Chris Nandor" <pudge@x.example.com>},
q{"Andy Wardley" <abw@cre.canon.co.uk>},
q{"Nicholas Clark" <nick@c.example.org>},
q{chip@valinux.com},
q{perl5-porters@p.example.org},
q{"'advocacy@p.example.org '" <advocacy@p.example.org>},
q{"Tom Christiansen" <tchrist@chthon.perl.com>},
q{"'Jon Orwant'" <orwant@media.mit.edu>},
q{"brian d foy" <tidbit@sri.net>},
q{"Brent Michalski" <brent@perlguy.net>},
q{"'Elaine -HFB- Ashton '" <elaine@chaos.example.edu>},
q{"'Elaine -HFB- Ashton'" <elaine@chaos.example.edu>},
q{"Gabor Szabo" <gabor@trt.example.biz>},
q{"'David E. Wheeler'" <David@whl.example.net>},
q{"Chip Salzenberg" <chip@valinux.com>},
q{"Elaine -HFB- Ashton" <elaine@chaos.example.edu>},
q{"Peter Scott" <Peter@PSDT.com>},
q{"'Ask Bjoern Hansen'" <ask@p.example.org>},
q{"'Larry Wall'" <larry@wall.org>},
q{"Helton, Brandon" <bhelton@h.h.example.com>},
q{"Greg Norris \(humble visionary genius\)" <nextrightmove@bang.example.net>},
q{advocacy@p.example.org},
q{"Greg Norris humble visionary genius\\"" <nextrightmove@bang.example.net>},
q{"perl-advocacy" <advocacy@p.example.org>},
q{"'Madeline Schnapp '" <madeline@oreilly.com>},
q{"Michael G Schwern" <schwern@x.example.com>},
q{"'Andy Lester'" <andy@pet.example.com>},
q{perl6-language@p.example.org},
q{"'Rich Bowen'" <rbowen@rc.example.com>},
q{tidbit@sri.net},
q{"Calvin Lee" <bodyshock911@hotmail.com>},
q{"David H. Adler" <dha@panix.com>},
q{"'Adam Turoff'" <adam.turoff@s.example.net>},
q{"'Pamela Carter'" <pcarter150@comcast.net>},
q{"Rich Bowen" <rbowen@rc.example.com>},
q{"Jan Dubois" <jand@ExamPle.com>},
q{marsneedswomen@happyfunball.pm.org},
q{"Madeline Schnapp" <madeline@oreilly.com>},
q{"Jason W. May" <jasonmay@example.name>},
q{"David E. Wheeler" <David@Wheeler.net>},
q{"Turoff, Adam" <adam.turoff@s.example.net>},
q{"'bwarnock@capita.com'" <bwarnock@capita.com>},
q{"Bas A. Schulte" <bschulte@zeelandnet.nl>},
q{"Michael R. Wolf" <MichaelRunningWolf@att.net>},
q{"G. Wade Johnson" <gwadej@normal.example.coop>},
q{"Piers Cawley" <pdcawley@bofh.org.uk>},
q{"Bradley M. Kuhn" <bkuhn@ebb.org>},
q{"Nathan Torkington" <gnat@frii.com>},
q{Ben_Tilly@trepp.com},
q{"'John Porter'" <jdporter@min.net>},
q{"'. Jerry a'" <JerryPanshen@aol.example.aero>},
q{"Paul Prescod" <paul@co.example.va>},
q{"Adam Turoff" <adam.turoff@s.example.net>},
q{"Uri Guttman" <uri@stemsystems.com>},
q{"'David H. Adler '" <dha@panix.com>},
q{"Jason W. May" <jmay@x.example.com>},
q{betsy@oreilly.com},
q{"Andreas J. Koenig" <andreas.koenig@example.net>},
q{"'Doucette, Bob'" <BDoucette@tesent.com>},
q{"'''advocacy@p.example.org ' ' '" <advocacy@p.example.org>},
q{madeline@oreilly.com},
q{"'Mark Mielke'" <markm@nortelnetworks.com>},
q{"Brian Wilson" <bwilson@songline.com>},
q{simon@brecon.co.uk},
q{"Dave Cross" <dave@dave.org.uk>},
q{"Curtis Poe" <cp@onsitetech.com>},
q{"'Shlomi Fish'" <shlomif@vipe.technion.ac.il>},
q{"'Chris Nandor'" <pudge@x.example.com>},
q{"David Grove" <pete@petes-place.com>},
q{"Betsy Waliszewski" <betsy@oreilly.com>},
q{"Clinton A. Pierce" <clintp@geeksalad.org>},
q{admin+=E6=96=B0=E5=8A=A0=E5=9D=A1_Weblog@test.sxt.example.info},
q{pudge@x.example.com},
q{"'Steve Lane'" <sml@zfx.com>},
q{"''advocacy@p.example.org ' '" <advocacy@p.example.org>},
q{"'london-list@happyfunball.pm.org'" <london-list@happyfunball.pm.org>},
q{"Alan Olsen" <alan@svr.example.museum>},
q{"'Gabor Szabo'" <gabor@trt.example.biz>},
q{"Bas A.Schulte" <bschulte@zeelandnet.nl>},
q{"'perl-hackers@stlouis.pm.org'" <perl-hackers@stlouis.pm.org>},
q{"Brammer, Phil" <PBRA01@CONAGRAFROZEN.COM>},
q{"'duff@x.example.com'" <duff@x.example.com>},
q{"advocacy" <advocacy@p.example.org>});
};

1;

==> Convert-YText-0.2.tar.gz: Convert-YText-0.2/t/corpus.pl <==
# Data originally from t/tests.t in Email::Address 1.892.
# License is the same as this module.
use utf8;
sub corpus {
return (
q{"Edwards, Darryl" <Darryl.Edwards@adc.com>},
q{"Chris Devers" <cdevers@boston.com>},
q{"Greg Norris" <nextrightmove@bang.example.net> (humble visionary genius)},
q{"Frank Schmuck, CFO" <fschmuck@l.example.org>},
q{regn@ExamPle.com},
q{"'abigail@foad.example.biz'" <abigail@foad.example.biz>},
q{"'advocacy@p.example.org'" <advocacy@p.example.org>},
q{"Horsley Tom" <Tom.Horsley@ccur.com>},
q{"'Tom Christiansen'" <tchrist@chthon.perl.com>},
q{"Chris Nandor" <pudge@x.example.com>},
q{"Andy Wardley" <abw@cre.canon.co.uk>},
q{"Nicholas Clark" <nick@c.example.org>},
q{chip@valinux.com},
q{perl5-porters@p.example.org},
q{"'advocacy@p.example.org '" <advocacy@p.example.org>},
q{"Tom Christiansen" <tchrist@chthon.perl.com>},
q{"'Jon Orwant'" <orwant@media.mit.edu>},
q{"brian d foy" <tidbit@sri.net>},
q{"Brent Michalski" <brent@perlguy.net>},
q{"'Elaine -HFB- Ashton '" <elaine@chaos.example.edu>},
q{"'Elaine -HFB- Ashton'" <elaine@chaos.example.edu>},
q{"Gabor Szabo" <gabor@trt.example.biz>},
q{"'David E. Wheeler'" <David@whl.example.net>},
q{"Chip Salzenberg" <chip@valinux.com>},
q{"Elaine -HFB- Ashton" <elaine@chaos.example.edu>},
q{"Peter Scott" <Peter@PSDT.com>},
q{"'Ask Bjoern Hansen'" <ask@p.example.org>},
q{"'Larry Wall'" <larry@wall.org>},
q{"Helton, Brandon" <bhelton@h.h.example.com>},
q{"Greg Norris \(humble visionary genius\)" <nextrightmove@bang.example.net>},
q{advocacy@p.example.org},
q{"Greg Norris humble visionary genius\\"" <nextrightmove@bang.example.net>},
q{"perl-advocacy" <advocacy@p.example.org>},
q{"'Madeline Schnapp '" <madeline@oreilly.com>},
q{"Michael G Schwern" <schwern@x.example.com>},
q{"'Andy Lester'" <andy@pet.example.com>},
q{perl6-language@p.example.org},
q{"'Rich Bowen'" <rbowen@rc.example.com>},
q{tidbit@sri.net},
q{"Calvin Lee" <bodyshock911@hotmail.com>},
q{"David H. Adler" <dha@panix.com>},
q{"'Adam Turoff'" <adam.turoff@s.example.net>},
q{"'Pamela Carter'" <pcarter150@comcast.net>},
q{"Rich Bowen" <rbowen@rc.example.com>},
q{"Jan Dubois" <jand@ExamPle.com>},
q{marsneedswomen@happyfunball.pm.org},
q{"Madeline Schnapp" <madeline@oreilly.com>},
q{"Jason W. May" <jasonmay@example.name>},
q{"David E. Wheeler" <David@Wheeler.net>},
q{"Turoff, Adam" <adam.turoff@s.example.net>},
q{"'bwarnock@capita.com'" <bwarnock@capita.com>},
q{"Bas A. Schulte" <bschulte@zeelandnet.nl>},
q{"Michael R. Wolf" <MichaelRunningWolf@att.net>},
q{"G. Wade Johnson" <gwadej@normal.example.coop>},
q{"Piers Cawley" <pdcawley@bofh.org.uk>},
q{"Bradley M. Kuhn" <bkuhn@ebb.org>},
q{"Nathan Torkington" <gnat@frii.com>},
q{Ben_Tilly@trepp.com},
q{"'John Porter'" <jdporter@min.net>},
q{"'. Jerry a'" <JerryPanshen@aol.example.aero>},
q{"Paul Prescod" <paul@co.example.va>},
q{"Adam Turoff" <adam.turoff@s.example.net>},
q{"Uri Guttman" <uri@stemsystems.com>},
q{"'David H. Adler '" <dha@panix.com>},
q{"Jason W. May" <jmay@x.example.com>},
q{betsy@oreilly.com},
q{"Andreas J. Koenig" <andreas.koenig@example.net>},
q{"'Doucette, Bob'" <BDoucette@tesent.com>},
q{"'''advocacy@p.example.org ' ' '" <advocacy@p.example.org>},
q{madeline@oreilly.com},
q{"'Mark Mielke'" <markm@nortelnetworks.com>},
q{"Brian Wilson" <bwilson@songline.com>},
q{simon@brecon.co.uk},
q{"Dave Cross" <dave@dave.org.uk>},
q{"Curtis Poe" <cp@onsitetech.com>},
q{"'Shlomi Fish'" <shlomif@vipe.technion.ac.il>},
q{"'Chris Nandor'" <pudge@x.example.com>},
q{"David Grove" <pete@petes-place.com>},
q{"Betsy Waliszewski" <betsy@oreilly.com>},
q{"Clinton A. Pierce" <clintp@geeksalad.org>},
q{admin+=E6=96=B0=E5=8A=A0=E5=9D=A1_Weblog@test.sxt.example.info},
q{pudge@x.example.com},
q{"'Steve Lane'" <sml@zfx.com>},
q{"''advocacy@p.example.org ' '" <advocacy@p.example.org>},
q{"'london-list@happyfunball.pm.org'" <london-list@happyfunball.pm.org>},
q{"Alan Olsen" <alan@svr.example.museum>},
q{"'Gabor Szabo'" <gabor@trt.example.biz>},
q{"Bas A.Schulte" <bschulte@zeelandnet.nl>},
q{"'perl-hackers@stlouis.pm.org'" <perl-hackers@stlouis.pm.org>},
q{"Brammer, Phil" <PBRA01@CONAGRAFROZEN.COM>},
q{"'duff@x.example.com'" <duff@x.example.com>},
q{"advocacy" <advocacy@p.example.org>},
# utf8 tests
q{"Brián Wïlşøn" <bwilson@songline.com>},
q{simon@brecon.co.uk},
q{"D☃ve Cr⌣ss" <dave@dave.org.uk>},
q{"C∪rtεs P⊕e" <cp@onsitetech.com>},
q{"'Shlωomη Fish'" <shlomif@vipe.technion.ac.il>},
q{"'ChrӀs Nℵndor'" <pudge@x.example.com>},
)
};

1;
